PALM-meteo: palmmeteo.config.ConfigObj Class Reference

PALM-meteo

Public Member Functions | List of all members
palmmeteo.config.ConfigObj Class Reference
Inheritance diagram for palmmeteo.config.ConfigObj:
[legend]
Collaboration diagram for palmmeteo.config.ConfigObj:
[legend]

## Public Member Functions
def | __init__ (self, parent=None, name=None)
def | __getattr__ (self, name)
def | __getitem__ (self, key)
def | __contains__ (self, key)
def | __iter__ (self)

## Detailed Description

    A recursive object within a hierarchical configuration, representing
    a (sub)section as a dictionary from the YAML configuration file. Child
    nodes may be accessed both by the dot notation (section.setting) and the
    item notation (section['setting']).

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo.config.ConfigObj.__init__ | ( |  | self,
|  |  | parent = `None`,
|  |  | name = `None`
| ) |  |

## Member Function Documentation

## ◆ __contains__()

def palmmeteo.config.ConfigObj.__contains__ | ( |  | self,
|  |  | key
| ) |  |

## ◆ __getattr__()

def palmmeteo.config.ConfigObj.__getattr__ | ( |  | self,
|  |  | name
| ) |  |

## ◆ __getitem__()

def palmmeteo.config.ConfigObj.__getitem__ | ( |  | self,
|  |  | key
| ) |  |

## ◆ __iter__()

def palmmeteo.config.ConfigObj.__iter__ | ( |  | self | ) |

The documentation for this class was generated from the following file:

- palmmeteo/config.py